@@ -4,6 +4,7 @@ import copy
 import math
 import pandas as pd
 import time
+from pprint import pprint
 from.function import is_number, col_is_number, keep_drop_judge
 
 # 最高10类数量占比
@@ -309,17 +310,17 @@ class DataPretreatment:
         if keep:
             if self.field_dict:
                 keep_df = pd.DataFrame(data={'field': keep, 'name': keep_name})
-                print('含有过多的缺失值但因在白名单内而保留的字段:\n', keep_df)
             else:
                 keep_df = pd.DataFrame(data={'field': keep})
-                print('含有过多的缺失值但因在白名单内而保留的字段:\n', keep_df)
+            print('含有过多的缺失值但因在白名单内而保留的字段:')
+            pprint(keep_df)
         if drop:
             if self.field_dict:
                 drop_df = pd.DataFrame(data={'field': drop, 'name': drop_name})
-                print('因过多的缺失值而被舍弃的字段:\n', drop_df)
             else:
                 drop_df = pd.DataFrame(data={'field': drop})
-                print('因过多的缺失值而被舍弃的字段:\n', drop_df)
+            print('因过多的缺失值而被舍弃的字段:')
+            pprint(drop_df)
         self.col_dict['drop_col'].extend(drop)
         end = time.time()
         if self.time_cost:
@@ -394,37 +395,43 @@ class DataPretreatment:
                 df = pd.DataFrame(data={'field': meaningless_keep, 'name': meaningless_keep_name})
             else:
                 df = pd.DataFrame(data={'field': meaningless_keep})
-            print('无意义但因白名单而保留的字段:\n', df)
+            print('无意义但因白名单而保留的字段:')
+            pprint(df)
         if low_kind_keep:
             if self.field_dict:
                 df = pd.DataFrame(data={'field': low_kind_keep, 'name': low_kind_keep_name})
             else:
                 df = pd.DataFrame(data={'field': low_kind_keep})
-            print('过少种类但因白名单而保留的字段:\n', df)
+            print('过少种类但因白名单而保留的字段:')
+            pprint(df)
         if multi_kind_keep:
             if self.field_dict:
                 df = pd.DataFrame(data={'field': multi_kind_keep, 'name': multi_kind_keep_name})
             else:
                 df = pd.DataFrame(data={'field': multi_kind_keep})
-            print('过多种类且不集中但因白名单而保留的字段:\n', df)
+            print('过多种类且不集中但因白名单而保留的字段:')
+            pprint(df)
         if meaningless_drop:
             if self.field_dict:
                 df = pd.DataFrame(data={'field': meaningless_drop, 'name': meaningless_drop_name})
             else:
                 df = pd.DataFrame(data={'field': meaningless_drop})
-            print('因无意义而舍弃的字段:\n', df)
+            print('因无意义而舍弃的字段:')
+            pprint(df)
         if low_kind_drop:
             if self.field_dict:
                 df = pd.DataFrame(data={'field': low_kind_drop, 'name': low_kind_drop_name})
             else:
                 df = pd.DataFrame(data={'field': low_kind_drop})
-            print('因过少的种类而舍弃的字段:\n', df)
+            print('因过少的种类而舍弃的字段:')
+            pprint(df)
         if multi_kind_drop:
             if self.field_dict:
                 df = pd.DataFrame(data={'field': multi_kind_drop, 'name': multi_kind_drop_name})
             else:
                 df = pd.DataFrame(data={'field': multi_kind_drop})
-            print('因种类过多且不集中而被舍弃的字段:\n', df)
+            print('因种类过多且不集中而被舍弃的字段:')
+            pprint(df)
         drop_col.extend(meaningless_drop)
         drop_col.extend(low_kind_drop)
         drop_col.extend(multi_kind_drop)
