@@ -2,6 +2,7 @@ import copy
 import time
 import pandas as pd
 import numpy as np
+from pprint import pprint
 import scipy.stats as st
 from sklearn.ensemble import RandomForestClassifier
 from .data_pretreatment import col_is_number
@@ -413,7 +414,8 @@ class FeatureAnalysis:
                 df = pd.DataFrame(data={'field': corr_drop, 'name': corr_drop_name})
             else:
                 df = pd.DataFrame(data={'field': corr_drop})
-            print('因相关性而被舍弃的字段:\n', df)
+            print('因相关性而被舍弃的字段:')
+            pprint(df)
         return corr_drop
 
     def auto_bin_col(
@@ -438,7 +440,7 @@ class FeatureAnalysis:
         if type_ == 'num_cla_col':
             bins_df, iv = num_bin(data, col, label, self.final_box, self.after_pretreatment)
         if type_ == 'num_col':
-            data = data[[col, label]].copy()
+            data = data[[col, label]].copy().astype(float)
             data["q_cut"], bins = pd.qcut(data[col], retbins=True, q=self.init_box, duplicates="drop")
             count_y0 = data.loc[data[label] == 0].groupby(by="q_cut")[label].count()
             count_y1 = data.loc[data[label] == 1].groupby(by="q_cut")[label].count()
@@ -471,7 +473,7 @@ class FeatureAnalysis:
                 print('字段:%s, 字段名:%s' % (col, self.field_dict[col]))
         else:
             print('字段:', col)
-        print(bins_df)
+        pprint(bins_df)
         print('iv值:', iv)
         return bins_df, iv
 
