@@ -1,6 +1,7 @@
 import copy
 import time
 import pandas as pd
+from pprint import pprint
 from sklearn.ensemble import RandomForestClassifier
 from .feature_analysis import cross_woe_iv
 from .feature_analysis import FeatureAnalysis
@@ -256,13 +257,15 @@ class FeatureProject(FeatureAnalysis):
                 df = pd.DataFrame(data={'field': iv_keep, 'name': iv_keep_name})
             else:
                 df = pd.DataFrame(data={'field': iv_keep})
-            print('iv小于给定的阈值但因在白名单内而被保留的字段:\n', df)
+            print('iv小于给定的阈值但因在白名单内而被保留的字段:')
+            pprint(df)
         if iv_drop:
             if self.field_dict:
                 df = pd.DataFrame(data={'field': iv_drop, 'name': iv_drop_name})
             else:
                 df = pd.DataFrame(data={'field': iv_drop})
-            print('因iv小于给定的阈值而被舍弃的字段:\n', df)
+            print('因iv小于给定的阈值而被舍弃的字段:')
+            pprint(df)
         end = time.time()
         if self.time_cost:
             print('耗时:', round(end - start, 4))
@@ -304,7 +307,8 @@ class FeatureProject(FeatureAnalysis):
             df = pd.DataFrame(data={'field': importance_list})
             if self.field_dict:
                 df['name'] = df['field'].map(lambda x: self.field_dict[x] if x in self.field_dict else x)
-            print('因重要性小于给定的阈值而被剔除的字段:\n', df)
+            print('因重要性小于给定的阈值而被剔除的字段:')
+            pprint(df)
         end = time.time()
         if self.time_cost:
             print('耗时:', round(end - start, 4))
@@ -359,7 +363,8 @@ class FeatureProject(FeatureAnalysis):
                 df = pd.DataFrame(data={'field': field, 'name': name})
             else:
                 df = pd.DataFrame(data={'field': field})
-            print('衍生的字段:\n', df)
+            print('衍生的字段:')
+            pprint(df)
         if self.time_cost:
             print('耗时:', round(end - start, 4))
         return data, derive_list
