@@ -2,6 +2,7 @@
 import time
 import numpy as np
 from sklearn.model_selection import train_test_split
+from pprint import pprint
 import pandas as pd
 from sklearn.ensemble import RandomForestClassifier
 from sklearn.metrics import classification_report, accuracy_score, confusion_matrix, f1_score
@@ -11,7 +12,6 @@ try:
     from sklearn.externals import joblib
 except ImportError:
     import joblib
-# from .function import rfc_2d_section
 
 
 version = lgb.__version__
@@ -42,15 +42,9 @@ def function():
     pass
 
 
-def rfc_model_importance(x_train, x_val, y_train, y_val, max_depth, weight):
-    model = RandomForestClassifier(n_jobs=-1, class_weight={0: 1, 1: weight},
-                                   n_estimators=100, max_depth=max_depth, random_state=1)
-    model.fit(x_train, y_train)
-    pre_train = model.predict(x_train)
-    pre_val = model.predict(x_val)
-    feature_importance = pd.DataFrame(data={
-        'feature_names': x_train.columns, 'importance': model.feature_importances_.round(4)})
-    feature_importance = feature_importance.sort_values('importance', ascending=False)
+def output(importance, y_train, y_val, pre_train, pre_val, field_dict):
+    if field_dict is not None:
+        importance['name'] = importance['feature'].map(field_dict)
     print(confusion_matrix(y_train, pre_train))
     print(classification_report(y_train, pre_train, digits=4))
     print('在训练集下的精度为：', accuracy_score(y_train, pre_train))
@@ -58,6 +52,20 @@ def rfc_model_importance(x_train, x_val, y_train, y_val, max_depth, weight):
     print(confusion_matrix(y_val, pre_val))
     print(classification_report(y_val, pre_val, digits=4))
     print('在验证集下的精度为：', accuracy_score(y_val, pre_val))
+    print('特征重要性:')
+    pprint(importance)
+
+
+def rfc_model_importance(x_train, x_val, y_train, y_val, max_depth, weight, field_dict):
+    model = RandomForestClassifier(n_jobs=-1, class_weight={0: 1, 1: weight},
+                                   n_estimators=100, max_depth=max_depth, random_state=1)
+    model.fit(x_train, y_train)
+    pre_train = model.predict(x_train)
+    pre_val = model.predict(x_val)
+    feature_importance = pd.DataFrame(data={
+        'feature': x_train.columns, 'importance': model.feature_importances_.round(4)})
+    feature_importance = feature_importance.sort_values('importance', ascending=False)
+    output(feature_importance, y_train, y_val, pre_train, pre_val, field_dict)
     return model, feature_importance
 
 
@@ -211,22 +219,6 @@ def rfc_adjust_parameter(x_train, x_val, y_train, y_val, max_depth, weight, bala
                                     balance, fitting, parameter_dict)
 
 
-def get_rfc_score(
-    x_train: pd.DataFrame,
-    x_val: pd.DataFrame,
-    y_train: pd.Series,
-    y_val: pd.Series,
-    max_depth: int,
-    weight: float,
-):
-    model = RandomForestClassifier(n_jobs=-1, class_weight={0: 1, 1: weight},
-                                   n_estimators=150, max_depth=max_depth, random_state=1)
-    model.fit(x_train, y_train)
-    pre_val = model.predict(x_val)
-    score = f1_score(y_val, pre_val)
-    return score
-
-
 class ModelBuild:
     """
     划分数据集
@@ -238,6 +230,7 @@ class ModelBuild:
     def __init__(
             self,
             baseline: str = 'RF',
+            field_dict: dict = None,
             max_depth: int = None,
             weight: float = None,
             lgb_params: dict = None,
@@ -248,9 +241,6 @@ class ModelBuild:
             is_evaluate: bool = False,
             evaluate_func: function = None,
             is_adjust_parameter: bool = False,
-            # max_depth_range: list = None,
-            # num_leaves_range: list = None,
-            # weight_range: list = None,
             time_cost: bool = True,
             **kwargs
     ):
@@ -285,6 +275,7 @@ class ModelBuild:
             train_test_split内的参数
         """
         self.baseline = baseline
+        self.field_dict = field_dict
         self.max_depth = max_depth
         self.weight = weight
         self.lgb_params = lgb_params
@@ -311,6 +302,7 @@ class ModelBuild:
             data: pd.DataFrame,
             label: str,
             baseline: str = None,
+            filed_dict: dict = None,
             max_depth: int = None,
             weight: float = None,
             lgb_params: dict = None,
@@ -324,6 +316,7 @@ class ModelBuild:
             **kwargs
     ):
         self.baseline = self.baseline if baseline is None else baseline
+        self.field_dict = self.field_dict if filed_dict is None else filed_dict
         self.max_depth = self.max_depth if max_depth is None else max_depth
         self.weight = self.weight if weight is None else weight
         self.lgb_params = self.lgb_params if lgb_params is None else lgb_params
@@ -357,16 +350,21 @@ class ModelBuild:
     def fit_transform(
         self,
         data: pd.DataFrame,
+        prob: bool = False
     ):
+        """
+        prob: bool
+            输出概率值
+        """
         pre = None
         if self.baseline in model_name['RF']:
             pre = self.rfc_model.predict(data)
         elif self.baseline in model_name['LGB']:
             pre = self.lgb_model.predict(data)
-            pre = np.where(pre > 0.5, 1, 0)
+            pre = pre if prob else np.where(pre > 0.5, 1, 0)
         elif self.baseline in model_name['XGB']:
             pre = self.xgb_model.predict(data)
-            pre = np.where(pre > 0.5, 1, 0)
+            pre = pre if prob else np.where(pre > 0.5, 1, 0)
         pre = pd.Series(pre)
         pre.index = data.index
         pre_df = pd.concat([data, pd.DataFrame(data={'pre': pre})], axis=1)
@@ -392,7 +390,8 @@ class ModelBuild:
             weight = round(data[data[label] == 0][label].count() / data[data[label] == 1][label].count(), 3)
         else:
             weight = self.weight
-        model, feature_importance = rfc_model_importance(x_train, x_val, y_train, y_val, max_depth, weight)
+        model, feature_importance = rfc_model_importance(
+            x_train, x_val, y_train, y_val, max_depth, weight, self.field_dict)
         return model, feature_importance
 
     def rfc_auto_adjust_parameter(
@@ -407,27 +406,13 @@ class ModelBuild:
               (1, 1, round(balance, 4), round(fitting, 4)))
         max_depth, weight = rfc_adjust_parameter(x_train, x_val, y_train, y_val, 1, 1, balance, fitting)
         print('最终max_depth: %s, 最终weight: %s' % (max_depth, weight))
-        model, feature_importance = rfc_model_importance(x_train, x_val, y_train, y_val, max_depth, weight)
+        model, feature_importance = rfc_model_importance(
+            x_train, x_val, y_train, y_val, max_depth, weight, self.field_dict)
         end = time.time()
         if self.time_cost:
             print('耗时:', round(end - start, 4))
         return model, feature_importance
 
-    # def rfc_param_search(
-    #     self,
-    #     data: pd.DataFrame,
-    #     label: str
-    # ):
-    #     start = time.time()
-    #     max_depth_range = [1, 10] if self.max_depth_range is None else self.max_depth_range
-    #     weight_range = [0, 10] if self.weight_range is None else self.weight_range
-    #     opt_depth, opt_weight, opt_score = rfc_2d_section(data, label, max_depth_range, weight_range, 0.38197,
-    #                                                       self.get_rfc_score)
-    #     end = time.time()
-    #     if self.time_cost:
-    #         print('耗时:', round(end - start, 4))
-    #     return opt_depth, opt_weight
-
     def lgb_fit(
             self,
             data: pd.DataFrame,
@@ -481,19 +466,13 @@ class ModelBuild:
                 model = lgb.train(lgb_params, train_data, self.epoch, valid_sets=[train_data, val_data],
                                   early_stopping_rounds=self.early_stopping, verbose_eval=self.verbose)
         importance = model.feature_importance() / (model.feature_importance().sum())
-        importance = pd.DataFrame(data={'feature_names': x_train.columns, 'importance': importance.round(4)})
+        importance = pd.DataFrame(data={'feature': x_train.columns, 'importance': importance.round(4)})
         importance = importance.sort_values('importance', ascending=False)
         pre_train = model.predict(x_train)
         pre_val = model.predict(x_val)
         pre_train = np.where(pre_train >= 0.5, 1, 0)
         pre_val = np.where(pre_val >= 0.5, 1, 0)
-        print(confusion_matrix(y_train, pre_train))
-        print(classification_report(y_train, pre_train, digits=4))
-        print('在训练集下的精度为：', accuracy_score(y_train, pre_train))
-        print('=' * 55)
-        print(confusion_matrix(y_val, pre_val))
-        print(classification_report(y_val, pre_val, digits=4))
-        print('在验证集下的精度为：', accuracy_score(y_val, pre_val))
+        output(importance, y_train, y_val, pre_train, pre_val, self.field_dict)
         return model, importance
 
     def lgb_cal_fitting(
@@ -586,55 +565,18 @@ class ModelBuild:
         model = lgb_init(x_train, x_val, y_train, y_val, num_leaves, weight,
                          self.epoch, self.early_stopping, self.is_evaluate, self.evaluate_func)
         importance = model.feature_importance() / (model.feature_importance().sum())
-        importance = pd.DataFrame(data={'feature_names': x_train.columns, 'importance': importance.round(4)})
+        importance = pd.DataFrame(data={'feature': x_train.columns, 'importance': importance.round(4)})
         importance = importance.sort_values('importance', ascending=False)
         pre_train = model.predict(x_train)
         pre_val = model.predict(x_val)
         pre_train = np.where(pre_train >= 0.5, 1, 0)
         pre_val = np.where(pre_val >= 0.5, 1, 0)
-        print(confusion_matrix(y_train, pre_train))
-        print(classification_report(y_train, pre_train, digits=4))
-        print('在训练集下的精度为：', accuracy_score(y_train, pre_train))
-        print('=' * 55)
-        print(confusion_matrix(y_val, pre_val))
-        print(classification_report(y_val, pre_val, digits=4))
-        print('在验证集下的精度为：', accuracy_score(y_val, pre_val))
+        output(importance, y_train, y_val, pre_train, pre_val, self.field_dict)
         end = time.time()
         if self.time_cost:
             print('耗时:', round(end - start, 4))
         return model, importance
 
-    # def get_lgb_score(
-    #     self,
-    #     x_train: pd.DataFrame,
-    #     x_val: pd.DataFrame,
-    #     y_train: pd.Series,
-    #     y_val: pd.Series,
-    #     num_leaves: int,
-    #     weight: float
-    # ):
-    #     model = lgb_init(x_train, x_val, y_train, y_val, num_leaves, weight,
-    #                      self.epoch, self.early_stopping, self.is_evaluate, self.evaluate_func)
-    #     pre_val = model.predict(x_val)
-    #     pre_val = np.where(pre_val >= 0.5, 1, 0)
-    #     score = f1_score(y_val, pre_val)
-    #     return score
-
-    # def lgb_param_search(
-    #     self,
-    #     data: pd.DataFrame,
-    #     label: str
-    # ):
-    #     start = time.time()
-    #     num_leaves_range = [25, 200] if self.num_leaves_range is None else self.num_leaves_range
-    #     weight_range = [0, 10] if self.weight_range is None else self.weight_range
-    #     opt_num_leaves, opt_weight, opt_score = rfc_2d_section(
-    #         data, label, num_leaves_range, weight_range, 0.38197, self.get_lgb_score)
-    #     end = time.time()
-    #     if self.time_cost:
-    #         print('耗时:', round(end - start, 4))
-    #     return opt_num_leaves, opt_weight
-
     def xgb_fit(
         self,
         data: pd.DataFrame,
@@ -672,20 +614,14 @@ class ModelBuild:
         else:
             model = xgb.train(dtrain=train_data, num_boost_round=self.epoch, evals=watchlist,
                               early_stopping_rounds=self.early_stopping, verbose_eval=self.verbose, params=xgb_params)
-        importance = pd.DataFrame(list(model.get_score().items()), columns=['feature_names', 'importance'])
+        importance = pd.DataFrame(list(model.get_score().items()), columns=['feature', 'importance'])
         importance = importance.sort_values('importance', ascending=False)
         importance['importance'] = importance['importance'] / importance['importance'].sum()
         pre_train = model.predict(train_data)
         pre_val = model.predict(val_data)
         pre_train = np.where(pre_train > 0.5, 1, 0)
         pre_val = np.where(pre_val > 0.5, 1, 0)
-        print(confusion_matrix(y_train, pre_train))
-        print(classification_report(y_train, pre_train, digits=4))
-        print('在训练集下的精度为：', accuracy_score(y_train, pre_train))
-        print('=' * 60)
-        print(confusion_matrix(y_val, pre_val))
-        print(classification_report(y_val, pre_val, digits=4))
-        print('在验证集下的精度为：', accuracy_score(y_val, pre_val))
+        output(importance, y_train, y_val, pre_train, pre_val, self.field_dict)
         return model, importance
 
     def xgb_cal_fitting(
@@ -785,56 +721,19 @@ class ModelBuild:
         model, train_data, val_data = xgb_init(
             x_train, x_val, y_train, y_val, max_depth, weight,
             self.epoch, self.early_stopping, self.is_evaluate, self.evaluate_func)
-        importance = pd.DataFrame(list(model.get_score().items()), columns=['feature_names', 'importance'])
+        importance = pd.DataFrame(list(model.get_score().items()), columns=['feature', 'importance'])
         importance = importance.sort_values('importance', ascending=False)
         importance['importance'] = importance['importance'] / importance['importance'].sum()
         pre_train = model.predict(train_data)
         pre_val = model.predict(val_data)
         pre_train = np.where(pre_train >= 0.5, 1, 0)
         pre_val = np.where(pre_val >= 0.5, 1, 0)
-        print(confusion_matrix(y_train, pre_train))
-        print(classification_report(y_train, pre_train, digits=4))
-        print('在训练集下的精度为：', accuracy_score(y_train, pre_train))
-        print('=' * 55)
-        print(confusion_matrix(y_val, pre_val))
-        print(classification_report(y_val, pre_val, digits=4))
-        print('在验证集下的精度为：', accuracy_score(y_val, pre_val))
+        output(importance, y_train, y_val, pre_train, pre_val, self.field_dict)
         end = time.time()
         if self.time_cost:
             print('耗时:', round(end - start, 4))
         return model, importance
 
-    # def get_xgb_score(
-    #     self,
-    #     x_train: pd.DataFrame,
-    #     x_val: pd.DataFrame,
-    #     y_train: pd.Series,
-    #     y_val: pd.Series,
-    #     max_depth: int,
-    #     weight: float
-    # ):
-    #     model = xgb_init(x_train, x_val, y_train, y_val, max_depth, weight, self.epoch,
-    #                      self.early_stopping, self.is_evaluate, self.evaluate_func)
-    #     pre_val = model.predict(x_val)
-    #     pre_val = np.where(pre_val >= 0.5, 1, 0)
-    #     score = f1_score(y_val, pre_val)
-    #     return score
-
-    # def xgb_param_search(
-    #     self,
-    #     data: pd.DataFrame,
-    #     label: str
-    # ):
-    #     start = time.time()
-    #     max_depth_range = [2, 10] if self.max_depth_range is None else self.max_depth_range
-    #     weight_range = [0, 10] if self.weight_range is None else self.weight_range
-    #     opt_max_depth, opt_weight, opt_score = rfc_2d_section(
-    #         data, label, max_depth_range, weight_range, 0.38197, self.get_xgb_score)
-    #     end = time.time()
-    #     if self.time_cost:
-    #         print('耗时:', round(end - start, 4))
-    #     return opt_max_depth, opt_weight
-
     def reset_atr(self):
         self.rfc_model = None
         self.lgb_model = None
